@@ -10,16 +10,16 @@ import matplotlib.pyplot as plt
 
 
 NSTARS = 20
-NSTEPS = 1000
-TIMESTEP = 0.5 # years
+NSTEPS = int(1e3)
+TIMESTEP = 1 # years
 
 # Placeholder values, fixed
 teff = 5777
 radius = 6.96e8
 mass = 2.0e30
 
-max_velocity = 1000.0  # m/s
-xmin, xmax = 0.0, 2.838e+14 # meters
+max_velocity = 1e4  # m/s
+xmin, xmax = 0.0, 2.838e+15 # meters
 
 # Set up the Cluster
 stars = []
